pymlconf
========

.. image:: http://img.shields.io/pypi/v/pymlconf.svg
     :target: https://pypi.python.org/pypi/pymlconf

.. image:: https://requires.io/github/pylover/pymlconf/requirements.svg?branch=master
     :target: https://requires.io/github/pylover/pymlconf/requirements/?branch=master
     :alt: Requirements Status

.. image:: https://travis-ci.org/pylover/pymlconf.svg?branch=master
     :target: https://travis-ci.org/pylover/pymlconf

.. image:: https://coveralls.io/repos/github/pylover/pymlconf/badge.svg?branch=master
     :target: https://coveralls.io/github/pylover/pymlconf?branch=master

.. image:: https://img.shields.io/badge/license-MIT-brightgreen.svg
     :target: https://github.com/pylover/pymlconf/blob/master/LICENSE


Jump To:
^^^^^^^^

 * `Documentation <https://pylover.github.com/pymlconf/>`_
 * `Python package index <https://pypi.python.org/pypi/pymlconf>`_
 * `Source on github <https://github.com/pylover/pymlconf>`_

About
^^^^^

**pymlconf** (Python YAML Configuration Library) helps to easily manage
and access to your application configurations which was already Written
in `YAML <http://pyyaml.org>`__ language.


Installation
~~~~~~~~~~~~

Latest stable version:

.. code-block:: shell

   $ pip install pymlconf


Unit-Tests
~~~~~~~~~~

Install nose and change current directory to project's dir:

.. code-block:: shell

   $ cd path/to/pymlconf
   $ pip install -r requirements-dev.txt 
   $ pip install -e .

Running tests:

.. code-block:: shell

   $ nosetests
        
Or

.. code-block:: shell

   $ python setup.py test


Syntax Reference
~~~~~~~~~~~~~~~~

You can find the canonical syntax reference on
`PyYAML <http://pyyaml.org/wiki/PyYAMLDocumentation#YAMLsyntax>`__ site

